@@ -14,7 +14,7 @@ sub login_opts {
         my $key = "FASTLY_TEST_BASE_".uc($what);
         $opts{"base_${what}"} = $ENV{$key} if defined $ENV{$key};
     }
-    my @required = ("full" eq $mode) ? qw(user name password customer) : qw(api_key);
+    my @required = ("full" eq $mode) ? qw(user name password customer) : qw(api_key customer);
     foreach my $what (@required) {
         my $key = "FASTLY_TEST_".uc($what);
         die "You haven't set the environment variable $key\n" unless defined $ENV{$key};
